@@ -14,6 +14,11 @@ class Experiment(Enum):
         GC (str): Indicates a garbage collection experiment.
         HOST_STRESS_MEMORY (str): Indicates a Host stress memory experiment.
         HOST_STRESS_CPU (str): Indicates a Host stress CPU experiment.
+        NETWORK_PARTITION (str): Indicates Network Partition experiment.
+        NETWORK_BANDWIDTH (str): Indicates Network Bandwidth experiment.
+        HOST_READ_PAYLOAD (str): Indicates Host disk fault read payload experiment.
+        HOST_WRITE_PAYLOAD (str): Indicates Host disk fault write payload experiment.
+        HOST_FILL (str): Indicates Host disk fill experiment.
     """
     POD_FAILURE = "POD_FAILURE"
     POD_KILL = "POD_KILL"
@@ -27,3 +32,10 @@ class Experiment(Enum):
 
     HOST_STRESS_MEMORY = "HOST_STRESS_MEMORY"
     HOST_STRESS_CPU = "HOST_STRESS_CPU"
+
+    NETWORK_PARTITION = "NETWORK_PARTITION"
+    NETWORK_BANDWIDTH = "NETWORK_BANDWIDTH"
+
+    HOST_READ_PAYLOAD = "HOST_READ_PAYLOAD"
+    HOST_WRITE_PAYLOAD = "HOST_WRITE_PAYLOAD"
+    HOST_DISK_FILL = "HOST_DISK_FILL"
